@@ -73,11 +73,11 @@ function recover(commands, retries)
 
     count = 0
     while true do
-        local r = table.pack(pcall(commands))
+        local r = {pcall(commands)}
         if retries == nil or count < retries then
-            if r[1] then return table.unpack(r) end
+            if r[1] then return r end
         else
-            if not r[1] then return table.unpack(r) end
+            if not r[1] then return r end
         end
         collectgarbage()
         count = count + 1
